@@ -5,6 +5,16 @@ from Quartz import *
 
 import os
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTFrame (TestCase):
 
     def testTypes(self):
@@ -21,7 +31,7 @@ class TestCTFrame (TestCase):
         self.assertIsInstance(v, (int, long))
 
         setter = CTFramesetterCreateWithAttributedString(
-                CFAttributedStringCreate(None, u"hello", None))
+                CFAttributedStringCreate(None, b"hello".decode('latin1'), None))
         self.assertIsInstance(setter, CTFramesetterRef)
 
         path = CGPathCreateMutable()
