@@ -4,6 +4,11 @@ from CoreText import *
 from Foundation import NSArray
 import struct, sys
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTParagraphStyle (TestCase):
     def testTypes(self):
         self.assertIsCFType(CTParagraphStyleRef)
@@ -39,7 +44,15 @@ class TestCTParagraphStyle (TestCase):
         self.assertEqual(kCTParagraphStyleSpecifierParagraphSpacing, 11)
         self.assertEqual(kCTParagraphStyleSpecifierParagraphSpacingBefore, 12)
         self.assertEqual(kCTParagraphStyleSpecifierBaseWritingDirection, 13)
-        self.assertEqual(kCTParagraphStyleSpecifierCount, 14)
+
+        self.assertEqual(kCTParagraphStyleSpecifierMaximumLineSpacing, 14)
+        self.assertEqual(kCTParagraphStyleSpecifierMinimumLineSpacing, 15)
+        self.assertEqual(kCTParagraphStyleSpecifierLineSpacingAdjustment, 16)
+
+    @min_os_level("10.8")
+    def testConstants10_8(self):
+        pass
+        #self.assertEqual(kCTParagraphStyleSpecifierBoundsOptions, 17)
 
     def testStructs(self):
         v = CTParagraphStyleSetting()
@@ -63,7 +76,7 @@ class TestCTParagraphStyle (TestCase):
 
         ok, v = CTParagraphStyleGetTabStops(style)
         self.assertTrue(ok)
-        self.assertIsInstance(v, CFArrayRef)
+        self.assertIsInstance(v, NSArray)
         self.assertTrue(len(v))
         self.assertIsInstance(v[0], CTTextTabRef)
 
@@ -92,7 +105,7 @@ class TestCTParagraphStyle (TestCase):
         self.assertEqual(len(v), sizeof_CTWritingDirection)
 
         # And now the hard part: create a CTParagraphStyle with custom options
-        if sys.maxint > 2**32:
+        if sys.maxsize > 2**32:
             float_pack = "d"
         else:
             float_pack = "f"
@@ -117,26 +130,26 @@ class TestCTParagraphStyle (TestCase):
                 CTParagraphStyleSetting(
                     spec=kCTParagraphStyleSpecifierBaseWritingDirection,
                     valueSize=sizeof_CTWritingDirection,
-                    value=chr(kCTWritingDirectionRightToLeft)),
+                    value=chr(kCTWritingDirectionRightToLeft).encode('latin1')),
         )
         style = CTParagraphStyleCreate(options, len(options))
         self.assertIsInstance(style, CTParagraphStyleRef);
 
         ok, v = CTParagraphStyleGetTabStops(style)
         self.assertTrue(ok)
-        self.assertIsInstance(v, CFArrayRef)
+        self.assertIsInstance(v, NSArray)
         self.assertEqual(len(v), 2)
 
         ok, v = CTParagraphStyleGetValueForSpecifier(style,
                 kCTParagraphStyleSpecifierBaseWritingDirection, sizeof_CTWritingDirection, None)
         self.assertTrue(ok)
-        self.assertIsInstance(v, str)
-        self.assertEqual(v, chr(kCTWritingDirectionRightToLeft))
+        self.assertIsInstance(v, bytes)
+        self.assertEqual(v, chr(kCTWritingDirectionRightToLeft).encode('latin1'))
 
         ok, v = CTParagraphStyleGetValueForSpecifier(style,
                 kCTParagraphStyleSpecifierFirstLineHeadIndent, sizeof_CGFloat, None)
         self.assertTrue(ok)
-        self.assertIsInstance(v, str)
+        self.assertIsInstance(v, bytes)
         self.assertEqual(v, struct.pack(float_pack, 10.5))
 
 if __name__ == "__main__":
