@@ -2,6 +2,16 @@
 from PyObjCTools.TestSupport import *
 from CoreText import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestCTTypesetter (TestCase):
     def testTypes(self):
         self.assertIsCFType(CTTypesetterRef)
@@ -14,7 +24,7 @@ class TestCTTypesetter (TestCase):
     def testFunctions(self):
         self.assertIsInstance(CTTypesetterGetTypeID(), (int, long))
 
-        astring = CFAttributedStringCreate(None, u"hello world", None)
+        astring = CFAttributedStringCreate(None, b"hello world".decode('latin1'), None)
         self.assertIsInstance(astring, CFAttributedStringRef)
 
         self.assertResultIsCFRetained(CTTypesetterCreateWithAttributedString)
